@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from pathlib import Path
 from urllib.parse import quote_plus
 from xml.etree import ElementTree
@@ -6,7 +5,6 @@ from xml.etree import ElementTree
 from plexapi import log, settings, utils
 from plexapi.base import PlexObject, cached_data_property
 from plexapi.exceptions import BadRequest
-from plexapi.utils import deprecated
 
 
 @utils.registerPlexObject
@@ -231,18 +229,6 @@ class MediaPart(PlexObject):
         self._server.query(key, method=self._server._session.put, params=params)
         return self
 
-    @deprecated('Use "setSelectedAudioStream" instead.')
-    def setDefaultAudioStream(self, stream):
-        return self.setSelectedAudioStream(stream)
-
-    @deprecated('Use "setSelectedSubtitleStream" instead.')
-    def setDefaultSubtitleStream(self, stream):
-        return self.setSelectedSubtitleStream(stream)
-
-    @deprecated('Use "resetSelectedSubtitleStream" instead.')
-    def resetDefaultSubtitleStream(self):
-        return self.resetSelectedSubtitleStream()
-
 
 class MediaPartStream(PlexObject):
     """ Base class for media streams. These consist of video, audio, subtitles, and lyrics.
@@ -444,10 +430,6 @@ class AudioStream(MediaPartStream):
         params = {'subsample': subSample}
         return self.fetchItems(key, params=params)
 
-    @deprecated('Use "setSelected" instead.')
-    def setDefault(self):
-        return self.setSelected()
-
 
 @utils.registerPlexObject
 class SubtitleStream(MediaPartStream):
@@ -494,10 +476,6 @@ class SubtitleStream(MediaPartStream):
         """
         return self._parent().setSelectedSubtitleStream(self)
 
-    @deprecated('Use "setSelected" instead.')
-    def setDefault(self):
-        return self.setSelected()
-
 
 @utils.registerPlexObject
 class LyricStream(MediaPartStream):
@@ -1281,20 +1259,11 @@ class Agent(PlexObject):
             return self.findItems(self._data, cls=AgentMediaType)
         return []
 
-    @property
-    @deprecated('use "languageCodes" instead')
-    def languageCode(self):
-        return self.languageCodes
-
     def settings(self):
         key = f'/:/plugins/{self.identifier}/prefs'
         data = self._server.query(key)
         return self.findItems(data, cls=settings.Setting)
 
-    @deprecated('use "settings" instead')
-    def _settings(self):
-        return self.settings()
-
 
 class AgentMediaType(Agent):
     """ Represents a single Agent MediaType.
@@ -1317,11 +1286,6 @@ class AgentMediaType(Agent):
     def languageCodes(self):
         return self.listAttrs(self._data, 'code', etag='Language')
 
-    @property
-    @deprecated('use "languageCodes" instead')
-    def languageCode(self):
-        return self.languageCodes
-
 
 @utils.registerPlexObject
 class Availability(PlexObject):
