@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import os
 from urllib.parse import urlencode
 
@@ -16,7 +15,6 @@ from plexapi.media import Conversion, Optimized
 from plexapi.playlist import Playlist
 from plexapi.playqueue import PlayQueue
 from plexapi.settings import Settings
-from plexapi.utils import deprecated
 from requests.status_codes import _codes as codes
 
 # Need these imports to populate utils.PLEXOBJECTS
@@ -613,10 +611,6 @@ class PlexServer(PlexObject):
         self.query(f'/butler/{task}', method=self._session.post)
         return self
 
-    @deprecated('use "checkForUpdate" instead')
-    def check_for_update(self, force=True, download=False):
-        return self.checkForUpdate(force=force, download=download)
-
     def checkForUpdate(self, force=True, download=False):
         """ Returns a :class:`~plexapi.server.Release` object containing release info
             if an update is available or None if no update is available.
@@ -728,15 +722,6 @@ class PlexServer(PlexObject):
             backgroundProcessing = self.fetchItem('/playlists?type=42')
             return self.fetchItems(f'{backgroundProcessing.key}/items', cls=Optimized)
 
-    @deprecated('use "plexapi.media.Optimized.items()" instead')
-    def optimizedItem(self, optimizedID):
-        """ Returns single queued optimized item :class:`~plexapi.media.Video` object.
-            Allows for using optimized item ID to connect back to source item.
-        """
-
-        backgroundProcessing = self.fetchItem('/playlists?type=42')
-        return self.fetchItem(f'{backgroundProcessing.key}/items/{optimizedID}/items')
-
     def conversions(self, pause=None):
         """ Returns list of all :class:`~plexapi.media.Conversion` objects connected to server. """
         if pause is True:
@@ -1074,7 +1059,6 @@ class Account(PlexObject):
             data (ElementTree): Response from PlexServer used to build this object (optional).
 
         Attributes:
-            authToken (str): Plex authentication token to access the server.
             mappingError (str): Unknown
             mappingErrorMessage (str): Unknown
             mappingState (str): Unknown
@@ -1096,7 +1080,6 @@ class Account(PlexObject):
 
     def _loadData(self, data):
         """ Load attribute values from Plex XML response. """
-        self.authToken = data.attrib.get('authToken')
         self.username = data.attrib.get('username')
         self.mappingState = data.attrib.get('mappingState')
         self.mappingError = data.attrib.get('mappingError')
